)package test;
/**
 * <p>Title: Imager Image enhancement tool</p>
 * <p>Description: package for JPhotoBrush application</p>
 * <p>Copyright: Copyright (c) 2001</p>
 * <p>Company: Personal</p>
 * @author Tanveer Rameez
 * @version 1.0
 */

import imager.*;
import javax.swing.*;
import java.awt.event.*;
import java.awt.*;

//public class name must end with "Plugin" (case sensitive) and must implement imager.Plugin
public class TestPlugin implements imager.Plugin {
        //custom member variable
		ImageWrapper m_Wrapper;

		//must have a default constructor. This constructor will be
		//invoked by JPhotoBrush when loading this plugin
        public TestPlugin()
		{
        }

		//implemented method. This method is called when the Plugin menu item is clicked.
		//It is invoked in a separate thread.
        public void operate(ImageWrapper wrapper)
        {
		        System.out.println("testPlugin operate executed");
                m_Wrapper=wrapper;
				JFrame frame=null;
				//since wrapper is an interface to JPhotoBrush application, it is also a JFrame
		        if(wrapper instanceof JFrame) frame=(JFrame)wrapper;
				//display a dialog
				RGBSwapDialog rgbswapDlg=new RGBSwapDialog(this,frame,"RGB Swap",true);
				rgbswapDlg.show();
        }

		public String getAuthorName() {
                return "Tanveer Rameez";
        }

        public String getPluginName() {
                return "RGB Swap";
        }

		//custom method
		void execute(int type)
		{
		  //pass the Filter to be exected by ImageWrapper. the filter must extend
		  // DefaultImageFilter to be executed by ImageWrapper interface.
		  // This method is invoked by the RGBSwapDialog when it's OK button is clicked.
		   m_Wrapper.executeFilter(new RGBSwapFilter(type));
		}


}
//filter class
class RGBSwapFilter extends DefaultImageFilter
		{
		 public final static int SWAP_R_G=0;
		 public final static int SWAP_R_B=1;
		 public final static int SWAP_G_B=2;
		 int swapType;
		 RGBSwapFilter(int swapType )
		 {
		    this.swapType=swapType;
		 }

		 //implement method which performs the pixel processing
		 public int filterRGB(int x, int y, int p_Pixel)
           {
                int newPixel=0;
			  switch(swapType)
			  { // getPixel(int r,int g,int b), getRed(int pixel), getBlue(int pixel),getGreen(int pixel)
			    // are methods defined in the superclass DefaultImageFilter
				case SWAP_R_G : newPixel=getPixel(getGreen(p_Pixel),getRed(p_Pixel),getBlue(p_Pixel));break;
				case SWAP_R_B : newPixel=getPixel(getBlue(p_Pixel),getGreen(p_Pixel),getRed(p_Pixel));break;
				case SWAP_G_B : newPixel=getPixel(getRed(p_Pixel),getBlue(p_Pixel),getGreen(p_Pixel));break;
			  }
            return newPixel;
          }
		}

//dialog class
class RGBSwapDialog extends JDialog {
        JRadioButton jRadioButton1 = new JRadioButton();
        JRadioButton jRadioButton2 = new JRadioButton();
        JRadioButton jRadioButton3 = new JRadioButton();
        JButton jButton1 = new JButton();
        JButton jButton2 = new JButton();
	    TestPlugin Owner;
        public RGBSwapDialog(TestPlugin owner, Frame frame, String title, boolean modal) {
                super(frame, title, modal);
                try {
				       Owner=owner;
                        jbInit();
                        setSize(330,120);
						setLocationRelativeTo(frame);
                }
                catch(Exception ex) {
                        ex.printStackTrace();
                }
        }


        private void jbInit() throws Exception {
                jRadioButton1.setText("Red-Green");
				jRadioButton1.setSelected(true);
                jRadioButton1.setBounds(new Rectangle(8, 12, 103, 25));
                this.getContentPane().setLayout(null);
                jRadioButton2.setText("Red-Blue");
                jRadioButton2.setBounds(new Rectangle(115, 12, 103, 25));
                jRadioButton3.setText("Blue-Green");
                jRadioButton3.setBounds(new Rectangle(229, 12, 103, 25));
                jButton1.setBounds(new Rectangle(36, 56, 103, 32));
                jButton1.setText("   Ok   ");
                jButton1.addActionListener(new java.awt.event.ActionListener() {
                        public void actionPerformed(ActionEvent e) {
                                jButton1_actionPerformed(e);
                        }
                });
                jButton2.setBounds(new Rectangle(158, 55, 103, 32));
                jButton2.setText("Cancel");
                jButton2.addActionListener(new java.awt.event.ActionListener() {
                        public void actionPerformed(ActionEvent e) {
                                jButton2_actionPerformed(e);
                        }
                });
                this.getContentPane().add(jRadioButton1, null);
                this.getContentPane().add(jRadioButton2, null);
                this.getContentPane().add(jRadioButton3, null);
                this.getContentPane().add(jButton2, null);
                this.getContentPane().add(jButton1, null);
        }

        void jButton2_actionPerformed(ActionEvent e) {
                dispose();
        }

        void jButton1_actionPerformed(ActionEvent e) {
		    int type=(jRadioButton1.isSelected()?RGBSwapFilter.SWAP_R_G:
			       (jRadioButton2.isSelected()?RGBSwapFilter.SWAP_R_B:RGBSwapFilter.SWAP_R_G));
			dispose();
			Owner.execute(type);
        }
}